==> flutter_mylibrary-0.0.28.tar.gz: lib/base/bloc/smartrefresh_bloc.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/http_error.dart';
import 'bloc_provider.dart.dart';



abstract class SmartRefreshBlocBase extends PullToRefreshBloc {

  bool requestSuccess = false;

  @override
  void dispose() {
    // TODO: implement dispose
  }


  @override
  void initState() {
    eventBus.on().listen((event) {
      if(event is HttpError){
        requestSuccess = false;
      }else{
        requestSuccess = true;
      }
    });
  }


  /// 添加空布局
  Widget buildEmptyWidget(String message, {Widget emptyWidget}){
    return emptyWidget == null? Container(
      alignment: Alignment.center,
      child: Text(
          message
      ),
    ) : emptyWidget;
  }

  Widget buildFirstRefreshWidget(){
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        new CircularProgressIndicator(),
        Gaps.vGap10,
        new Text(
          '加载中',
          style: TextStyle(color: mainTextColor),
        )
      ],
    );
  }


  ///自定义头部
  Header headerCreate({BuildContext context});

  ///自定义脚部
  Footer footerCreate({BuildContext context});



  EasyRefresh getEasyRefresh(Widget widget,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, Widget firstRefreshWidget, bool openLoadMore = true, BuildContext context}){
    return EasyRefresh(
      header: headerCreate(context: context),
      footer: footerCreate(context: context),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      child: widget,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
          easyRefreshController.finishRefresh();
          emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad(noMore: value, success: true);
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,
    );

  }



  EasyRefresh getEasyRefreshCustom(List<Widget> slivers,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, bool openLoadMore = true, BuildContext context}){
    return EasyRefresh.custom(
      header: headerCreate(context: context),
      footer: footerCreate(context: context),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      slivers: slivers,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
            easyRefreshController.finishRefresh();
            emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad(noMore: value, success: true);
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,

    );
  }




}


///下拉刷新Bloc
abstract class PullToRefreshBloc extends BlocBase {
  ///加载数据
  Future getData({data});

  ///刷新
  Future onRefresh({data});

  ///更多
  Future<bool> onLoadMore({data});
}

==> flutter_mylibrary-0.0.29.tar.gz: lib/base/bloc/smartrefresh_bloc.dart <==
import 'package:flui/flui.dart';
import 'package:flutter/material.dart';
import 'package:flutter_easyrefresh/easy_refresh.dart';
import 'package:flutter_mylibrary/config/const.dart';
import 'package:flutter_mylibrary/http/http_error.dart';
import 'bloc_provider.dart.dart';



abstract class SmartRefreshBlocBase<T> extends PullToRefreshBloc {

  bool requestSuccess = false;

  @override
  void dispose() {
    // TODO: implement dispose
  }


  @override
  void initState() {
    eventBus.on().listen((event) {
      if(event is HttpError){
        requestSuccess = false;
      }else{
        requestSuccess = true;
      }
    });
  }


  /// 添加空布局
  Widget buildEmptyWidget(String message, {Widget emptyWidget}){
    return emptyWidget == null? Container(
      alignment: Alignment.center,
      child: Text(
          message
      ),
    ) : emptyWidget;
  }

  Widget buildFirstRefreshWidget(){
    return Column(
      mainAxisAlignment: MainAxisAlignment.center,
      children: <Widget>[
        new CircularProgressIndicator(),
        Gaps.vGap10,
        new Text(
          '加载中',
          style: TextStyle(color: mainTextColor),
        )
      ],
    );
  }


  ///自定义头部
  Header headerCreate({BuildContext context});

  ///自定义脚部
  Footer footerCreate({BuildContext context});


  int page = 0;

  List<T> data = [];


  ///自定义第一页页数
  int firstPage();

  ///自定义一页数量
  int pageSize();


  EasyRefresh getEasyRefresh(Widget widget,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, Widget firstRefreshWidget, bool openLoadMore = true, BuildContext context}){
    return EasyRefresh(
      header: headerCreate(context: context),
      footer: footerCreate(context: context),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      child: widget,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
          easyRefreshController.finishRefresh();
          emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad(noMore: value, success: true);
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,
    );

  }



  EasyRefresh getEasyRefreshCustom(List<Widget> slivers,  EasyRefreshController easyRefreshController, {dataRefresh, dataOnLoad, Widget emptyWidget, bool firstRefresh = true, bool openLoadMore = true, BuildContext context}){
    return EasyRefresh.custom(
      header: headerCreate(context: context),
      footer: footerCreate(context: context),
      controller: easyRefreshController,
      enableControlFinishLoad: true,
      enableControlFinishRefresh: true,
      slivers: slivers,
      onRefresh: ()async{
        onRefresh(data: dataRefresh).then((value) {
            easyRefreshController.finishRefresh();
            emptyWidget = null;
        });
      },
      onLoad: openLoadMore? ()async{
        onLoadMore(data: dataOnLoad).then((value) {
          easyRefreshController.finishLoad(noMore: value, success: true);
        });
      }: null,
      emptyWidget: requestSuccess? null : emptyWidget,
      firstRefreshWidget: firstRefresh?  buildFirstRefreshWidget() : null,
      firstRefresh: firstRefresh,

    );
  }




}


///下拉刷新Bloc
abstract class PullToRefreshBloc extends BlocBase {
  ///加载数据
  Future getData({data});

  ///刷新
  Future onRefresh({data});

  ///更多
  Future<bool> onLoadMore({data});
}
